@@ -9,6 +9,7 @@ import shutil
 import logging
 from dpath import util
 from collections import defaultdict
+from distutils.util import strtobool
 from mergedeep import merge, Strategy
 from tgwrapper.tghelper import tghelper
 from jinja2 import Environment, FileSystemLoader, exceptions
@@ -40,13 +41,20 @@ def is_path_exist(*args):
             sys.exit(1)
 
 
-def delete_tg_cache(list_of_dirs):
+def delete_tg_cache(to_delete: str) -> None:
     """
-    :param list_of_dirs:  List of directories to be deleted
+    :param to_delete:  To delete the terragrunt cache folder
     :return: None
     """
-    for dir_to_delete in list_of_dirs:
-        shutil.rmtree(os.getcwd() + '/' + dir_to_delete, ignore_errors=True)
+    del_flag = 0
+    list_of_dirs = [".terragrunt-cache"]
+    try:
+        del_flag = strtobool(to_delete)
+    except ValueError as e:
+        logging.error("Invalid value for boolean variable")
+    if del_flag == 1:
+        for dir_to_delete in list_of_dirs:
+            shutil.rmtree(os.getcwd() + '/' + dir_to_delete, ignore_errors=True)
 
 
 def get_terragrunt_modules_list():
@@ -170,7 +178,7 @@ def write_config_file(env_override_file, config_template, env, region):
 
 
 def run_terragrunt(action, config_dir, config_template, env,
-                   profile, region, terraform_args, tg_mod_dir) -> None:
+                   profile, region, terraform_args, tg_mod_dir, delete_cache) -> None:
     """
     :param action:
     :param config_dir:
@@ -184,7 +192,7 @@ def run_terragrunt(action, config_dir, config_template, env,
     """
     project_root = find_project_dir()
     logging.info(f"PROJECT_ROOT is set to - {project_root}")
-    delete_tg_cache([".terragrunt-cache"])
+    delete_tg_cache(delete_cache)
 
     # Arguments mock
     env_conf_file_path = f"{project_root}/{config_dir}/{env}_override.yml"
@@ -262,7 +270,7 @@ def main():
 
     run_terragrunt(action=str(options.action), config_dir=options.config_dir, config_template=options.config_template,
                    env=env, profile=options.profile, region=region, terraform_args=terraform_args,
-                   tg_mod_dir=options.tg_dir)
+                   tg_mod_dir=options.tg_dir, delete_cache=options.delete_cache)
 
 
 if __name__ == "__main__":
